Socket

Struct Socket 

pub struct Socket<Req, Resp> { /* private fields */ }
A hRPC socket.

Sockets only handle pings if you call .receive_message() continously. See the respective socket transports used for more information on their behaviour. The socket transports are located in crate::common::transport.

Implementations

Source

impl<Req, Resp> Socket<Req, Resp>

pub async fn send_error(&mut self, err: HrpcError) -> Result<(), SocketError>

Send an error over the socket.

Source

impl<Req, Resp> Socket<Req, Resp>
where Req: PbMsg, Resp: PbMsg + Default,

pub async fn receive_message(&mut self) -> Result<Resp, SocketError>

Receive a message from the socket.

Notes
  • This will block until getting a message (unless an error occurs).
  • This will handle ping messages.
pub async fn send_message(&mut self, req: Req) -> Result<(), SocketError>

Send a message over the socket.

pub async fn ping(&mut self) -> Result<(), SocketError>

Send a ping over the socket.

pub async fn close(self) -> Result<(), SocketError>

Close the socket.

pub fn split(self) -> (WriteSocket<Req>, ReadSocket<Resp>)

Split this socket into the write half and the read half.

pub fn combine( write: WriteSocket<Req>, read: ReadSocket<Resp>, ) -> Result<Self, CombineError>

Combine a write and read half back to a socket.

Errors
  • Returns CombineError if the socket halfs aren’t split from the same socket.