BoxResponse

Type Alias BoxResponse 

pub type BoxResponse = Response<()>;
A response that has a message type of (). Used in places where the response message type is not important.

Aliased Type

pub struct BoxResponse { /* private fields */ }